==> ZenTaoPMS.16.5.php5.3_5.6.zip: zentaopms/extension/max/baseline/lang/zh-cn.php <==
<?php
$lang->baseline->common         = '基线';
$lang->baseline->name           = '名称';
$lang->baseline->template       = '文档模板';
$lang->baseline->catalog        = '文档目录';
$lang->baseline->createTemplate = '创建模板';
$lang->baseline->editTemplate   = '编辑模板';
$lang->baseline->templateTitle  = '模板名称';
$lang->baseline->templateType   = '模板类型';
$lang->baseline->docType        = '文档类型';
$lang->baseline->docContent     = '文档正文';
$lang->baseline->url            = '文档URL';
$lang->baseline->manageChild    = '维护子目录';
$lang->baseline->addedBy        = '由谁添加';
$lang->baseline->addedDate      = '添加时间';
$lang->baseline->files          = '附件';
$lang->baseline->view           = '模板详情';
$lang->baseline->editBook       = '编辑手册';
$lang->baseline->manageBook     = '维护章节';
$lang->baseline->addCatalogTip  = '暂时还没有章节，';
$lang->baseline->editArticle    = '编辑内容';
$lang->baseline->articleView    = '文章内容';
$lang->baseline->editChapter    = '编辑章节';
$lang->baseline->chapter        = '章节';
$lang->baseline->chapterName    = '章节名称';
$lang->baseline->baseInfo       = '基本信息';
$lang->baseline->chapterType    = '数据来源';
$lang->baseline->delete         = '删除';

$lang->baseline->docTypeList['html']      = '富文本';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['url']       = '链接';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = '手动输入';
$lang->baseline->chapterTypeList['system'] = '系统数据';

$lang->baseline->confirmDelete = '您确定要删除吗?';

$lang->baseline->setting      = '设置';
$lang->baseline->version      = '版本号';
$lang->baseline->reviewer     = '评审人';
$lang->baseline->padding      = '序号补零';
$lang->baseline->reviewerRole = '评审人角色';

$lang->baseline->confirm[1] = '补零';
$lang->baseline->confirm[0] = '不补零';

$lang->baseline->objectList[''] = '';
$lang->baseline->objectList['PP']   = '项目计划';
$lang->baseline->objectList['QAP']  = '质量保证计划';
$lang->baseline->objectList['CMP']  = '配置管理计划';
$lang->baseline->objectList['ITP']  = '集成测试计划';
$lang->baseline->objectList['URS']  = '用户需求说明书';
$lang->baseline->objectList['SRS']  = '软件需求规格说明书';
$lang->baseline->objectList['HLDS'] = '概要设计说明书';
$lang->baseline->objectList['DDS']  = '详细设计说明书';
$lang->baseline->objectList['DBDS'] = '数据库设计文档';
$lang->baseline->objectList['ADS']  = '接口设计文档';
$lang->baseline->objectList['Code'] = '程序代码';
$lang->baseline->objectList['ITTC'] = '集成测试用例';
$lang->baseline->objectList['STP']  = '系统测试计划';
$lang->baseline->objectList['STTC'] = '系统测试用例';
$lang->baseline->objectList['UM']   = '用户手册';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = '年月日';
$lang->baseline->versionForm['date2'] = '年-月-日';
$lang->baseline->versionForm['fixed'] = '固定值';
$lang->baseline->versionForm['user']  = '操作者';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';

==> ZenTaoPMS.17.1.php7.0.zip: zentaopms/extension/max/baseline/lang/zh-cn.php <==
<?php
$lang->baseline->common         = '基线';
$lang->baseline->name           = '名称';
$lang->baseline->template       = '文档模板';
$lang->baseline->catalog        = '文档目录';
$lang->baseline->createTemplate = '创建模板';
$lang->baseline->editTemplate   = '编辑模板';
$lang->baseline->templateTitle  = '模板名称';
$lang->baseline->templateType   = '模板类型';
$lang->baseline->docType        = '文档类型';
$lang->baseline->docContent     = '文档正文';
$lang->baseline->url            = '文档URL';
$lang->baseline->manageChild    = '维护子目录';
$lang->baseline->addedBy        = '由谁添加';
$lang->baseline->addedDate      = '添加时间';
$lang->baseline->files          = '附件';
$lang->baseline->view           = '模板详情';
$lang->baseline->editBook       = '编辑手册';
$lang->baseline->manageBook     = '维护章节';
$lang->baseline->addCatalogTip  = '暂时还没有章节，';
$lang->baseline->editArticle    = '编辑内容';
$lang->baseline->articleView    = '文章内容';
$lang->baseline->editChapter    = '编辑章节';
$lang->baseline->chapter        = '章节';
$lang->baseline->chapterName    = '章节名称';
$lang->baseline->baseInfo       = '基本信息';
$lang->baseline->chapterType    = '数据来源';
$lang->baseline->delete         = '删除';
$lang->baseline->urlDoc         = '链接';

$lang->baseline->docTypeList['html']      = '富文本';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = '手动输入';
$lang->baseline->chapterTypeList['system'] = '系统数据';

$lang->baseline->confirmDelete = '您确定要删除吗?';

$lang->baseline->setting      = '设置';
$lang->baseline->version      = '版本号';
$lang->baseline->reviewer     = '评审人';
$lang->baseline->padding      = '序号补零';
$lang->baseline->reviewerRole = '评审人角色';

$lang->baseline->confirm[1] = '补零';
$lang->baseline->confirm[0] = '不补零';

$lang->baseline->objectList[''] = '';
$lang->baseline->objectList['PP']   = '项目计划';
$lang->baseline->objectList['QAP']  = '质量保证计划';
$lang->baseline->objectList['CMP']  = '配置管理计划';
$lang->baseline->objectList['ITP']  = '集成测试计划';
$lang->baseline->objectList['URS']  = '用户需求说明书';
$lang->baseline->objectList['SRS']  = '软件需求规格说明书';
$lang->baseline->objectList['HLDS'] = '概要设计说明书';
$lang->baseline->objectList['DDS']  = '详细设计说明书';
$lang->baseline->objectList['DBDS'] = '数据库设计文档';
$lang->baseline->objectList['ADS']  = '接口设计文档';
$lang->baseline->objectList['Code'] = '程序代码';
$lang->baseline->objectList['ITTC'] = '集成测试用例';
$lang->baseline->objectList['STP']  = '系统测试计划';
$lang->baseline->objectList['STTC'] = '系统测试用例';
$lang->baseline->objectList['UM']   = '用户手册';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = '年月日';
$lang->baseline->versionForm['date2'] = '年-月-日';
$lang->baseline->versionForm['fixed'] = '固定值';
$lang->baseline->versionForm['user']  = '操作者';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';
